# This script tests hypotheses 1 & 2 in PNAS paper 
# "The confidence gap predicts the gender pay gap among STEM graduates."

install.packages("tidyverse")
install.packages("stargazer")
install.packages("boot")
install.packages("lfe")

library(tidyverse)
library(stargazer)
library(boot)
library(lfe)

data <- read.csv("data.csv", check.names = "FALSE")

# testing hypothesis 1: ========================================================
# women make less than men upon college exit ===================================
# when holding engineering and CS degrees ======================================

hyp1_m1 <- felm(data = data, log(yearly40hours52weeks) ~ female)
hyp1_m2 <- felm(data = data, log(yearly40hours52weeks) ~ female + 
             s3q49_felm + internship |
             s3q126 + schoolid + s3q43n_clean + q35gpa + s3q42 + s3q45)
hyp1_m3 <- felm(data = data, log(yearly40hours52weeks) ~ female  + etse_1 + 
             s3q49_felm + internship |
             s3q126 + schoolid + s3q43n_clean + q35gpa + s3q42 + s3q45)
hyp1_m4 <- felm(data = data, log(yearly40hours52weeks) ~ female  + s3q154_5_felm + 
             s3q49_felm + internship |
             s3q126 + schoolid + s3q43n_clean + q35gpa + s3q42 + s3q45)
hyp1_m5 <- felm(data = data, log(yearly40hours52weeks) ~ female  + s3q154_2_felm + 
             s3q49_felm + internship |
             s3q126 + schoolid + s3q43n_clean + q35gpa + s3q42 + s3q45)
hyp1_m6 <- felm(data = data, log(yearly40hours52weeks) ~ female  + etse_1 + s3q154_5_felm + s3q154_2_felm +
             s3q49_felm + internship |
             s3q126 + schoolid + s3q43n_clean + q35gpa + s3q42 + s3q45)

# generate LaTeX table with regression results 
stargazer(hyp1_m1, hyp1_m2, hyp1_m3, hyp1_m4, hyp1_m5, hyp1_m6)

# testing hypothesis 2: ========================================================
# whether or not self-efficacy mediates the relationship =======================
# between gender and salary for engineering and CS degree holders ==============

# step 1: examine relationship between engineering self-efficacy and being female
hyp2_m1 <- felm(data = data, etse_1 ~ female)
hyp2_m2 <- felm(data = data, etse_1 ~ female  + s3q49_felm + internship |
                  s3q126 + schoolid + s3q43n_clean + q35gpa + s3q42 + s3q45)

# generate LaTeX table with regression results 
stargazer(hyp2_m1, hyp2_m2)

# step 2: examine relaitonship between annual salary and engineering self-efficacy
hyp2_m3 <- felm(data = data, log(yearly40hours52weeks) ~ female)
hyp2_m4 <- felm(data = data, log(yearly40hours52weeks) ~ female + etse_1)
hyp2_m5 <- felm(data = data, log(yearly40hours52weeks) ~ female + etse_1 + s3q49_felm + internship |
             s3q126 + schoolid + s3q43n_clean + q35gpa + s3q42 + s3q45)

# generate LaTeX table with regression results 
stargazer(hyp2_m3, hyp2_m4, hyp2_m5)

# step 3: simple mediation analysis following Hayes' method (2017)

# create function to estimate indirect and direct effects from n bootstrap samples 
bs_fun <- function(formula_a, formula_b, data, indices) {
  d <- data[indices,] # resampling with replacement
  fit_a <- felm(formula_a, data = d)
  fit_b <- felm(formula_b, data = d)
  return(rbind(coef(fit_a), coef(fit_b)))
}

# use function above to obtain statistics from 1000 bootstrap samples
simple_med <- boot(data = data, 
                    statistic = bs_fun,
                    R = 1000, 
                    formula_a = etse_1 ~ female |
                      s3q126 + schoolid + s3q43n_clean + q35gpa + s3q42 + 
                      s3q45 + s3q49_felm + internship,
                    formula_b = log(yearly40hours52weeks) ~ female + etse_1 |
                      s3q126 + schoolid + s3q43n_clean + q35gpa + s3q42 + 
                      s3q45 + s3q49_felm + internship)

# indirect effect of X on Y ----------------------------------------------------
# obtain 1000 bootstrapped indirect efffects by multiplying a's and b's
simple_med_ab <- simple_med$t[,1] * simple_med$t[,4]

# calculate the average indirect efffect
mean(simple_med_ab)

# calcuate SE of 1000 bootstrapped indirect effects
sqrt(var(simple_med_ab))

# calculate 95% CI of 1000 bootstrapped indrect effects
quantile(simple_med_ab, c(0.05, 0.95))

# direct effect of X on Y ------------------------------------------------------
# obtain 1000 bootstrapped direct efffects by extracting c prime's
simple_med_c <- simple_med$t[,2]

# calculate the average direct effect
mean(simple_med_c)

# calcuate SE of 1000 bootstrapped direct effects
sqrt(var(simple_med_c))

# calculate 95% CI of 1000 bootstrapped direct effects
quantile(simple_med_c, c(0.05, 0.95))

# total effect of X on Y ------------------------------------------------------
# obtain 1000 bootstrapped total efffects by adding c prime's and a's and b's
simple_med_abc <- simple_med_ab + simple_med_c

# calculate the average direct effect
mean(simple_med_abc)

# calcuate SE of 1000 bootstrapped direct effects
sqrt(var(simple_med_abc))

# calculate 95% CI of 1000 bootstrapped direct effects
quantile(simple_med_abc, c(0.05, 0.95))

# propoprtion mediated ---------------------------------------------------------
# calculate proportion mediated: (ab / (c' + ab))
prop_mediated <- simple_med_ab / (simple_med_c + simple_med_ab)

# calculate the average proportion mediated
mean(prop_mediated)

# calcuate SE of 1000 bootstrapepd proprotions
sqrt(var(prop_mediated))

# calculate 95% CI of 1000 bootstrapped proportions
quantile(prop_mediated, c(0.05, 0.95))[[1]]

# create summary table
sum <- data.frame(Type = c("Indirect effect", "Direct effect", 
                           "Total effect", "Prop mediated"), 
                  Estimate = c(mean(simple_med_ab), mean(simple_med_c), 
                               mean(simple_med_abc), mean(prop_mediated)),
                  SE = c(sqrt(var(simple_med_ab)), sqrt(var(simple_med_c)), 
                         sqrt(var(simple_med_abc)), sqrt(var(prop_mediated))),
                  CI_Lower = c(quantile(simple_med_ab, c(0.05, 0.95))[[1]],
                                     quantile(simple_med_c, c(0.05, 0.95))[[1]],
                               quantile(simple_med_abc, c(0.05, 0.95))[[1]],
                                     quantile(prop_mediated, c(0.05, 0.95))[[1]]),
                  CI_Upper = c(quantile(simple_med_ab, c(0.05, 0.95))[[2]],
                                     quantile(simple_med_c, c(0.05, 0.95))[[2]],
                               quantile(simple_med_abc, c(0.05, 0.95))[[2]],
                                     quantile(prop_mediated, c(0.05, 0.95))[[2]]))
